# Changelog

<!--next-version-placeholder-->

## v0.3.0 (2023-06-20)
### Feature
* **310:** Support Python 3.10 ([`22e7081`](https://github.com/robinvandernoord/su6-plugin-demo/commit/22e708110986f3321691ba6576daec7bd87d10bb))

## v0.2.1 (2023-06-15)

### Fix

* Slightly change config to work with configuraptor ([`755e4de`](https://github.com/robinvandernoord/su6-plugin-demo/commit/755e4de013a8364e69a473d6e1d5f68e6c40c1d6))

## v0.2.0 (2023-06-08)
### Feature

* **demo:** Use plugin config 🎉 ([`6977e07`](https://github.com/robinvandernoord/su6-plugin-demo/commit/6977e07100d23feb0b61de6df856c5aa6c06c8f9))

### Documentation

* **examples:** Working code from su6/docs/plugins.md ([`a90b914`](https://github.com/robinvandernoord/su6-plugin-demo/commit/a90b9144b93f20fbbb867140f2aa528fcfba077d))

## v0.1.0 (2023-06-05)
### Feature

* Initial version of the demo plugin ([`dc02818`](https://github.com/robinvandernoord/su6-plugin-demo/commit/dc02818b5d361469fa0ca480eee7394628faad89))
